@@ -3,9 +3,9 @@ import datetime
 import hashlib
 import json
 import os
-from pathlib import Path
 import sys
 import tempfile
+from pathlib import Path
 
 from opensafely._vendor import requests
 
@@ -91,6 +91,9 @@ def update(codelists_dir=None):
 
 def check():
     codelists_dir = Path.cwd() / CODELISTS_DIR
+    if not codelists_dir.exists():
+        print(f"No '{CODELISTS_DIR}' directory present so nothing to check")
+        return True
     codelists = parse_codelist_file(codelists_dir)
     manifest_file = codelists_dir / MANIFEST_FILE
     if not manifest_file.exists():
@@ -109,7 +112,13 @@ def check():
         else:
             exit_with_prompt(f"No file found at '{CODELISTS_DIR}/{MANIFEST_FILE}'.")
     else:
-        manifest = json.loads(manifest_file.read_text())
+        try:
+            manifest = json.loads(manifest_file.read_text())
+        except json.decoder.JSONDecodeError:
+            exit_with_prompt(
+                f"'{CODELISTS_DIR}/{MANIFEST_FILE}' is invalid.\n"
+                "Note that this file is automatically generated and should not be manually edited.\n"
+            )
     all_ids = {codelist.id for codelist in codelists}
     ids_in_manifest = {f["id"] for f in manifest["files"].values()}
     if all_ids != ids_in_manifest:
@@ -166,8 +175,9 @@ def parse_codelist_file(codelists_dir):
     if not codelists_file.exists():
         exit_with_error(f"No file found at '{CODELISTS_DIR}/{CODELISTS_FILE}'")
     codelists = []
+    codelist_versions = {}
     for line in codelists_file.read_text().splitlines():
-        line = line.strip()
+        line = line.strip().rstrip("/")
         if not line or line.startswith("#"):
             continue
         tokens = line.split("/")
@@ -176,6 +186,17 @@ def parse_codelist_file(codelists_dir):
                 f"{line} does not match [project]/[codelist]/[version] "
                 "or user/[username]/[codelist]/[version]"
             )
+        line_without_version = "/".join(tokens[:-1])
+        existing_version = codelist_versions.get(line_without_version)
+        line_version = tokens[-1]
+        if existing_version == line_version:
+            exit_with_error(f"{line} is a duplicate of a previous line")
+        if existing_version is not None:
+            exit_with_error(
+                f"{line} conflicts with a different version of the same codelist: {existing_version}"
+            )
+        codelist_versions[line_without_version] = line_version
+
         url = f"https://codelists.opensafely.org/codelist/{line}/"
         filename = "-".join(tokens[:-1]) + ".csv"
         codelists.append(
